# Archiving, Deleting and Recovering Fact Sheets
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets#introduction)
  * [Archiving a Fact Sheet](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets#archiving-a-fact-sheet)
  * [Archiving Fact Sheets in Bulk](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets#archiving-fact-sheets-in-bulk)
  * [Viewing and Recovering the Archived Fact Sheets](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets#viewing-and-recovering-the-archived-fact-sheets)
  * [Deleting Fact Sheets](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets#deleting-fact-sheets)


Learn to archive fact sheets individually or in bulk and effortlessly view or recover archived fact sheets in SAP LeanIX.
